==> pmml-model-gwt-1.4.11-sources.jar: org/dmg/pmml/general_regression/BaselineStratum.java <==

package org.dmg.pmml.general_regression;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.HasValue;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.dmg.pmml.adapters.ObjectAdapter;
import org.dmg.pmml.adapters.RealNumberAdapter;
import org.jpmml.model.annotations.Added;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "baselineCells"
})
@XmlRootElement(name = "BaselineStratum", namespace = "http://www.dmg.org/PMML-4_3")
@Added((org.dmg.pmml.Version.PMML_4_0))
@JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY, getterVisibility = JsonAutoDetect.Visibility.NONE, isGetterVisibility = JsonAutoDetect.Visibility.NONE, setterVisibility = JsonAutoDetect.Visibility.NONE)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "value",
    "label",
    "maxTime",
    "extensions",
    "baselineCells"
})
public class BaselineStratum
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<BaselineStratum> , HasValue<BaselineStratum>
{

    @XmlAttribute(name = "value", required = true)
    @XmlJavaTypeAdapter(ObjectAdapter.class)
    @XmlSchemaType(name = "anySimpleType")
    @JsonProperty("value")
    private Object value;
    @XmlAttribute(name = "label")
    @JsonProperty("label")
    private String label;
    @XmlAttribute(name = "maxTime", required = true)
    @XmlJavaTypeAdapter(RealNumberAdapter.class)
    @JsonProperty("maxTime")
    private Number maxTime;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "BaselineCell", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("BaselineCell")
    private List<BaselineCell> baselineCells;
    private final static long serialVersionUID = 67305489L;

    public BaselineStratum() {
    }

    public BaselineStratum(
        @org.jpmml.model.annotations.Property("value")
        Object value,
        @org.jpmml.model.annotations.Property("maxTime")
        Number maxTime) {
        this.value = value;
        this.maxTime = maxTime;
    }

    @Override
    public Object getValue() {
        return value;
    }

    @Override
    public BaselineStratum setValue(
        @org.jpmml.model.annotations.Property("value")
        Object value) {
        this.value = value;
        return this;
    }

    public String getLabel() {
        return label;
    }

    public BaselineStratum setLabel(
        @org.jpmml.model.annotations.Property("label")
        String label) {
        this.label = label;
        return this;
    }

    public Number getMaxTime() {
        return maxTime;
    }

    public BaselineStratum setMaxTime(
        @org.jpmml.model.annotations.Property("maxTime")
        Number maxTime) {
        this.maxTime = maxTime;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public BaselineStratum addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasBaselineCells() {
        return ((this.baselineCells!= null)&&(this.baselineCells.size()> 0));
    }

    public List<BaselineCell> getBaselineCells() {
        if (baselineCells == null) {
            baselineCells = new ArrayList<BaselineCell>();
        }
        return this.baselineCells;
    }

    public BaselineStratum addBaselineCells(BaselineCell... baselineCells) {
        getBaselineCells().addAll(Arrays.asList(baselineCells));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasBaselineCells()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getBaselineCells());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.5.2-sources.jar: org/dmg/pmml/general_regression/BaselineStratum.java <==

package org.dmg.pmml.general_regression;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.HasValue;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.dmg.pmml.adapters.ObjectAdapter;
import org.dmg.pmml.adapters.RealNumberAdapter;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.ValueConstructor;

@XmlRootElement(name = "BaselineStratum", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions",
    "baselineCells"
})
@Added((org.dmg.pmml.Version.PMML_4_0))
@JsonRootName("BaselineStratum")
@JsonPropertyOrder({
    "value",
    "label",
    "maxTime",
    "extensions",
    "baselineCells"
})
public class BaselineStratum
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<BaselineStratum> , HasValue<BaselineStratum>
{

    @XmlAttribute(name = "value", required = true)
    @XmlJavaTypeAdapter(ObjectAdapter.class)
    @XmlSchemaType(name = "anySimpleType")
    @JsonProperty("value")
    private Object value;
    @XmlAttribute(name = "label")
    @JsonProperty("label")
    private String label;
    @XmlAttribute(name = "maxTime", required = true)
    @XmlJavaTypeAdapter(RealNumberAdapter.class)
    @JsonProperty("maxTime")
    private Number maxTime;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "BaselineCell", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("BaselineCell")
    private List<BaselineCell> baselineCells;
    private final static long serialVersionUID = 67371011L;

    public BaselineStratum() {
    }

    @ValueConstructor
    public BaselineStratum(
        @org.jpmml.model.annotations.Property("value")
        Object value,
        @org.jpmml.model.annotations.Property("maxTime")
        Number maxTime) {
        this.value = value;
        this.maxTime = maxTime;
    }

    @Override
    public Object getValue() {
        return value;
    }

    @Override
    public BaselineStratum setValue(
        @org.jpmml.model.annotations.Property("value")
        Object value) {
        this.value = value;
        return this;
    }

    public String getLabel() {
        return label;
    }

    public BaselineStratum setLabel(
        @org.jpmml.model.annotations.Property("label")
        String label) {
        this.label = label;
        return this;
    }

    public Number getMaxTime() {
        return maxTime;
    }

    public BaselineStratum setMaxTime(
        @org.jpmml.model.annotations.Property("maxTime")
        Number maxTime) {
        this.maxTime = maxTime;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public BaselineStratum addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasBaselineCells() {
        return ((this.baselineCells!= null)&&(this.baselineCells.size()> 0));
    }

    public List<BaselineCell> getBaselineCells() {
        if (baselineCells == null) {
            baselineCells = new ArrayList<BaselineCell>();
        }
        return this.baselineCells;
    }

    public BaselineStratum addBaselineCells(BaselineCell... baselineCells) {
        getBaselineCells().addAll(Arrays.asList(baselineCells));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasBaselineCells()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getBaselineCells());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
